0Pricing
CUDA Academy · 강의

하나의 포인터, 양쪽에서 사용하기

cudaMallocManaged의 작동 방식을 알아봅니다.

하나의 포인터, 양쪽에서 사용하기은(는) CoddyKit의 무료 CUDA Academy 강의입니다. 이것은 4개 중 1번째 강의입니다. 아래에서 전체 강의를 무료로 읽을 수 있으며, 내장 코드 에디터와 24/7 AI 튜터와 함께 브라우저에서 직접 실습할 수 있습니다. 이 강의는 CUDA Academy 학습 경로의 일부이며, 진행 상황이 웹과 CoddyKit 앱에 동기화됩니다. CUDA Academy 강의에는 총 4개의 강의가 포함되어 있습니다.

이 강의의 일부는 아직 번역되지 않았으며 영어로 표시됩니다.

The Two-Pointer Headache

So far you juggled two pointers: one for the host, one for the device. Unified Memory replaces that pain with a single pointer both sides can use. 🙂

Meet cudaMallocManaged

You allocate managed memory with cudaMallocManaged. It hands back one address that works in your CPU code and inside your kernels alike.

float *data;
cudaMallocManaged(&data, n * sizeof(float));

No More cudaMemcpy

The big win: you usually skip the manual copies. With managed memory the runtime moves data for you, so cudaMemcpy often disappears from your code.

Write on the Host

You can fill the buffer with ordinary CPU code right after allocating. The same pointer you got is a normal address your loops can touch.

for (int i = 0; i < n; i++)
    data[i] = i;

Read on the Device

Pass that exact pointer to your kernel and the GPU threads dereference it directly. One address serves both worlds with no translation step.

kernel<<<blocks, threads>>>(data, n);

Sync Before You Read Back

After a kernel writes managed data, call cudaDeviceSynchronize before the CPU reads it. That guarantees the GPU finished and results are visible.

kernel<<<b, t>>>(data, n);
cudaDeviceSynchronize();

Free It Like Any Buffer

Managed memory is still device memory, so you release it with cudaFree. There is no special managed-free call to remember.

cudaFree(data);

Less Boilerplate, Fewer Bugs

Because you delete the alloc-copy-launch-copy-free dance, your programs shrink. Fewer copies means fewer chances to mix up directions or sizes.

Great for Prototyping

Unified Memory is perfect when you want a kernel running fast. You prototype quickly, then optimize transfers later only where they actually matter.

It Is Not Free Magic

The data still has to travel across PCIe under the hood. Convenience is real, but performance can lag hand-tuned copies until you add hints later.

When to Reach for It

Choose managed memory for simpler code, deep pointer structures, or oversubscribing GPU memory. It shines when clarity matters more than raw peak speed.

Quick Check

Let us confirm how managed allocation differs from the classic flow.

Recap: One Pointer, Both Sides

You learned that cudaMallocManaged hands you one pointer for host and device, dropping most copies. Sync before reading, free with cudaFree. Nice work! 🎉

자주 묻는 질문

“하나의 포인터, 양쪽에서 사용하기” 강의는 무료인가요?

네 — “하나의 포인터, 양쪽에서 사용하기” 전체 내용을 이 웹사이트에서 무료로 읽을 수 있습니다. 인터랙티브하게 실습하려면(내장 코드 에디터와 24/7 AI 튜터), CoddyKit PRO로 업그레이드하면 CUDA Academy 강의 전체를 잠금 해제할 수 있습니다. CUDA Academy 강의에는 총 4개의 강의가 포함되어 있습니다.

“하나의 포인터, 양쪽에서 사용하기”에서 뭘 배우나요?

cudaMallocManaged의 작동 방식을 알아봅니다. 브라우저에서 직접 실행하는 실습 코드로 CUDA Academy을(를) 배우며, 24/7 AI 튜터가 강의를 진행하면서 질문에 답변해줍니다.

CUDA Academy을(를) 시작하는 데 경험이 필요한가요?

사전 경험은 필요하지 않습니다. CoddyKit의 CUDA Academy은(는) 초급자부터 고급 학습자까지를 위해 구성되어 있으므로, 여기서 시작하거나 처음부터 시작할 수 있으며 자신의 속도대로 진행할 수 있습니다. 이것은 4개 중 1번째 강의입니다.

“하나의 포인터, 양쪽에서 사용하기” 강의는 얼마나 걸리나요?

대부분의 CoddyKit 강의는 약 5~10분이 소요됩니다. 각 강의는 간결하고 인터랙티브하여 꾸준한 진행이 가능하며, 웹과 앱에서 중단한 부분부터 바로 시작할 수 있습니다.

이 CUDA Academy 강의에서 코드를 작성하고 실행할 수 있나요?

네. 모든 CUDA Academy 강의에는 내장 코드 에디터가 포함되어 있으므로, 브라우저에서 바로 실제 코드를 작성하고 실행한 후 즉시 AI 피드백을 받을 수 있습니다 — 로컬 설정이 필요 없습니다.

이 강의의 모든 강의

  1. 하나의 포인터, 양쪽에서 사용하기
  2. 필요할 때 페이지 이동하기
  3. cudaMemPrefetchAsync로 미리 가져오기
  4. cudaMemAdvise로 힌트 제공하기
← CUDA Academy(으)로 돌아가기